# Local
from .constants import Action
from .redirects import HttpResponseSeeOther, redirect_303
from .renderers import render_turbo_frame, render_turbo_stream
from .response import (
    TemplateFormResponse,
    TurboFrameResponse,
    TurboFrameTemplateResponse,
    TurboStreamResponse,
    TurboStreamStreamingResponse,
    TurboStreamTemplateResponse,
)
from .shortcuts import TurboFrame, TurboStream
from .template import render_turbo_frame_template, render_turbo_stream_template

__all__ = [
    "Action",
    "HttpResponseSeeOther",
    "TemplateFormResponse",
    "TurboFrame",
    "TurboFrameResponse",
    "TurboFrameTemplateResponse",
    "TurboStream",
    "TurboStreamResponse",
    "TurboStreamStreamingResponse",
    "TurboStreamTemplateResponse",
    "redirect_303",
    "render_turbo_frame",
    "render_turbo_frame_template",
    "render_turbo_stream",
    "render_turbo_stream_template",
]



# Local
from .constants import Action


def render_turbo_stream(action: Action, target: str, content: str = "") -> str:
    """Wraps content in correct <turbo-stream> tags.

    :param action: action type
    :param target: the DOM ID target of the stream
    :param content: content to be wrapped. Can be empty.

    :return: *<turbo-stream>* string
    """
    return f'<turbo-stream action="{action.value}" target="{target}"><template>{content.strip()}</template></turbo-stream>'


def render_turbo_frame(dom_id: str, content: str = "") -> str:
    """

    Wraps a response in correct *<turbo-frame>* tags.

    :param dom_id: a DOM ID present in the content
    :param content: content of the turbo-frame

    :return: *<turbo-frame>* string
    """
    return f'<turbo-frame id="{dom_id}">{content.strip()}</turbo-frame>'



#!/usr/bin/env python
# Third Party Libraries
from setuptools import setup

version = "0.0.22"

setup(
    name="django-turbo-response",
    version=version,
    author="Dan Jacob",
    author_email="danjac2018@gmail.com",
    url="https://github.com/hotwire-django/django-turbo-response",
    description="Hotwired/Turbo response helpers for Django",
    long_description=open("README.md").read() + "\n\n" + open("CHANGES.md").read(),
    long_description_content_type="text/markdown",
    license="MIT",
    python_requires=">=3.8",
    requires=["django (>=3.1)"],
    packages=["turbo_response"],
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)



# Standard Library
from typing import Callable

# Django
from django.http import HttpRequest, HttpResponse

# Local
from .constants import TURBO_STREAM_MIME_TYPE


class TurboStreamMiddleware:
    """Adds bool attribute 'accept_turbo_stream' to request if the Turbo Stream accept header is present."""

    def __init__(self, get_response: Callable[[HttpRequest], HttpResponse]):
        self.get_response = get_response

    def __call__(self, request: HttpRequest) -> HttpResponse:
        request.accept_turbo_stream = TURBO_STREAM_MIME_TYPE in request.headers.get(
            "Accept", ""
        )
        return self.get_response(request)



# Standard Library
import enum


class Action(enum.Enum):
    """Turbo-Stream action parameter"""

    APPEND = "append"
    PREPEND = "prepend"
    REMOVE = "remove"
    REPLACE = "replace"
    UPDATE = "update"


TURBO_STREAM_MIME_TYPE = "text/vnd.turbo-stream.html"
